@@ -34,7 +34,6 @@ VISOR_CONFIG = os.path.join(VISOR_DIR, 'config.json')
 # TODO: should be able to `visor console <container_id>` to recover from broken ssh
 # TODO: REPEATABLE should be taking state of all required machines not just cur
 # TODO: SNAPSHOT should be global/local to a machine
-# TODO: --keep-running vms should auto-sleep after 20 mins of inactivity
 # TODO: total time getting printed before error
 # TODO: clean up network after all containers in that network are gone
 # TODO: host CPU going crazy even when guest cpu is close to idle
@@ -468,7 +467,7 @@ def main():
 
   build_parser = subparsers.add_parser('build', help='Build a Visorfile')
   build_parser.add_argument('--keep-running', action='store_true')
-  build_parser.add_argument('--snapshot-on-failure', action='store_true')
+  build_parser.add_argument('--snapshot-on-failure', action='store', nargs='?', const=True, default=None)
   build_parser.add_argument('--build-env', dest='buildenvs', action='append', default=[])
   build_parser.add_argument('visorfile', help='The Visorfile to build')
   build_parser.set_defaults(func=do_build)
